@@ -8,7 +8,7 @@ SPVM::IO::Socket - Sockets
 
 =head1 Description
 
-L<SPVM::IO::Socket> class has methods for sockets.
+IO::Socket class in L<SPVM> represents a socket.
 
 =head1 Usage
   
@@ -20,23 +20,31 @@ IO::Socket is an abstract class.
 
 See L</"Well Known Child Classes"> about child classes of this class.
 
-=head2 Porting
-
-This class is a Perl's L<IO::Socket|IO::Socket> porting to L<SPVM>.
-
 =head2 Socket Constant Values
 
 See L<Sys::Socket::Constant|SPVM::Sys::Socket::Constant> about constant values for sockets.
 
 =head2 Goroutine
 
-IO::Socket class works with L<Go|SPVM::Go> class.
+Connect, accept, read, and write operations in IO::Socket class work with L<goroutines|SPVM::Go>.
 
-Sockets created with IO::Socket class are non-blocking sockets by default.
+Non-blocking mode of a L<IO::Socket|SPVM::IO::Socket> object is enabled.
 
-If a socket connect, accept, read, or write operation needs to wait for IO, the program passes control to a Goroutine.
+If an IO wait occurs, control is transferred to another goroutine.
 
-The control will return when IO waiting is finished or a timeout occurs.
+This allows you to write connect, accept, read, and write operations as if they were synchronous.
+
+=head1 Well Known Child Classes
+
+=over 2
+
+=item * L<IO::Socket::IP|SPVM::IO::Socket::IP>
+
+=item * L<IO::Socket::INET|SPVM::IO::Socket::INET>
+
+=item * L<IO::Socket::INET6|SPVM::IO::Socket::INET6>
+
+=back
 
 =head1 Super Class
 
@@ -48,30 +56,34 @@ L<IO::Handle|SPVM::IO::Handle>
 
 C<has Domain : protected int;>
 
-A protocol family, like C<AF_INET>, C<AF_INET6>, C<AF_UNIX>.
+A protocol family, such as C<AF_INET>, C<AF_INET6>, C<AF_UNIX>.
 
 =head2 Type
 
 C<has Type : protected int;>
 
-A socket type, like C<SOCK_STREAM>, C<SOCK_DGRAM>.
+A socket type, such as C<SOCK_STREAM>, C<SOCK_DGRAM>, C<SOCK_RAW>.
 
 =head2 Proto
 
 C<has Proto : protected ro int;>
 
-A particular protocol, normally this is set to 0.
+A socket protocol, such as C<IPPROTO_TCP>, C<IPPROTO_UDP>.
 
 =head2 Timeout
 
 C<has Timeout : protected double;>
 
-A timeout seconds for system calls that would set C<errno> to C<EWOULDBLOCK>, like C<read()>, C<write()>, C<connect()>, C<accept()>.
+A timeout seconds for read, write, connect, accept operations.
 
 =head2 Listen
 
 C<has Listen : protected int;>
 
+The number of listen backlog.
+
+=head1 Instance Methods
+
 =head2 init
 
 C<protected method init : void ($options : object[] = undef);>
@@ -84,11 +96,11 @@ The following options are available adding to the options for L<IO::Handle#init|
 
 =over 2
 
-=item * C<Domain> : Int = -1
+=item * C<Domain> : Int = 0
 
-=item * C<Type> : Int = -1
+=item * C<Type> : Int = 0
 
-=item * C<Proto> : Int = -1
+=item * C<Proto> : Int = 0
 
 =item * C<Timeout> : Double = 0.0
 
@@ -96,9 +108,13 @@ The following options are available adding to the options for L<IO::Handle#init|
 
 =back
 
-See also L<SPVM::Sys::Socket::Constant>.
+The blocking mode of the socket is set to non-blocking mode.
 
-=head1 Instance Methods
+=head2 DESTROY
+
+C<method DESTROY : void ();>
+
+Closes the socket by L</"close"> method if the socket is opened.
 
 =head2 sockdomain
 
@@ -130,17 +146,91 @@ C<method set_timeout : void ($timeout : double);>
 
 Sets L</"Timeout"> field to $timeout.
 
-=head2 DESTROY
+=head2 set_blocking
 
-C<method DESTROY : void ();>
+C<method set_blocking : void ($blocking : int);>
 
-A destructor. This method closes the socket by calling L</"close"> method if the socket is opened.
+This method is the same as L<IO::Handle#set_blocking|SPVM::IO::Handle/"set_blocking"> method, but if a true value is given to $blocking, an exception is thrown.
+
+Exceptions:
+
+Calling set_blocking method given a true value on an IO::Socket object is forbidden.
+
+=head2 socket
+
+C<protected method socket : void ();>
+
+Opens a socket using L</"Domain"> field, L</"Type"> field, and L</"Protocal"> field.
+
+L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field is set to the file descriptor of the socket.
+
+This method calls L<Sys#socket|Sys/"socket"> method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#socket|Sys/"socket"> method could be thrown.
+
+=head2 connect
+
+C<protected method connect : void ($sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
+
+Performs connect operation.
+
+This method calls L<Sys#connect> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and $sockaddr.
+
+If connect operation need to be performed again for IO wait, L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#connect> method could be thrown.
+
+=head2 bind
+
+C<protected method bind : void ($sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
+
+Perform bind operation.
+
+This method calls L<Sys#bind|SPVM::Sys|/"bind"> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and $sockaddr.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#bind|SPVM::Sys|/"bind"> method could be thrown.
+
+=head2 listen
+
+C<protected method listen : void ();>
+
+Does the same thing that L<listen|https://linux.die.net/man/2/listen> system call does given the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
+
+This method calls L<Sys#listen|SPVM::Sys|/"listen">.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#listen|SPVM::Sys|/"listen"> method could be thrown.
+
+=head2 accept
+
+C<method accept : L<IO::Socket|SPVM::IO::Socket> ($peer_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[] = undef);>
+
+Performs accept operation and returns a client socket object.
+
+The type of the returned object is the type of this instance.
+
+This method calls L<Sys#accept|SPVM::Sys|/"accept"> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and $peer_ref.
+
+If accept operation need to be performed again for IO wait, L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+
+$peer_ref at index 0 is set to a client socket address if specified.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#accept|SPVM::Sys|/"accept"> method could be thrown.
 
 =head2 shutdown
 
 C<method shutdown : void ($how : int);>
 
-Shuts down the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field given the way $how.
+Performs shutdown operation given the way $how.
 
 This method calls L<Sys#shutdown|SPVM::Sys/"shutdown"> method.
 
@@ -162,39 +252,51 @@ Exceptions thrown by L<Sys#shutdown|SPVM::Sys/"shutdown"> method could be thrown
 
 =head2 close
 
-C<method close : int ();>
+C<method close : void ();>
 
-Closes the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
+Performs close operation.
+
+This method calls L<Sys::Socket#close|SPVM::Sys::Socket/"close"> method
 
 Exceptions:
 
 If this socket is not opened or already closed, an excetpion is thrown.
 
-=head2 accept
-
-C<method accept : L<IO::Socket|SPVM::IO::Socket> ($peer_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[] = undef);>
-
-Does the same thing that L<accept|https://linux.die.net/man/2/accept> system call does given the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
-
-This method calls L<Sys#accept|SPVM::Sys|/"accept">.
-
-Exceptions:
-
-Exceptions thrown by L<Sys#accept|SPVM::Sys|/"accept"> method could be thrown.
-
 =head2 recvfrom
 
 C<method recvfrom : int ($buffer : mutable string, $length : int, $flags : int, $from_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[], $offset : int = 0)>
 
+Performs recvfrom operation and returns read length.
+
+This method calls L<Sys#recvfrom> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $buffer, $length, $flags, $from_ref, $offset, and returns its return value.
+
+If recvfrom operation need to be performed again for IO wait, L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#recvfrom> method could be thrown.
+
 =head2 sendto
 
 C<method sendto : int ($buffer : string, $flags : int, $to : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $length : int = -1, $offset : int = 0);>
 
+Performs sendto operation and returns write length.
+
+This method calls L<Sys#sendto> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $buffer, $flags, $to, $length, $offset, and returns its return value.
+
+If sendto operation need to be performed again for IO wait, L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+
+Exceptions:
+
+Exceptions thrown by L<Sys#sendto> method could be thrown.
+
 =head2 recv
 
 C<method recv : int ($buffer : mutable string, $length : int = -1, $flags : int = 0, $offset : int = 0);>
 
-Calls L</"recvfrom"> method given the arguments to this method with $from_ref set to C<undef> and returns its return value.
+Performs recv operation.
+
+Thie method just calls L</"recvfrom"> method given $buffer, $length, $flags, $from_ref set to undef, $offset, and returns its return value.
 
 Exceptions:
 
@@ -204,7 +306,9 @@ Exceptions thrown by L</"recvfrom"> method could be thrown.
 
 C<method send : int ($buffer : string, $flags : int = 0, $length : int = -1, $offset : int = 0);>
 
-Calls L</"sendto"> method given the arguments to this method with $to set to C<undef> and returns its return value.
+Performs send operation.
+
+This method just calls L</"sendto"> method given $buffer, $flags, $to set to 0, $length, $offset, and returns its return value.
 
 Exceptions:
 
@@ -214,21 +318,21 @@ Exceptions thrown by L</"sendto"> method could be thrown.
 
 C<method read : int ($buffer : mutable string, $length : int = -1, $offset : int = 0);>
 
-Reads the length $length of data from the stream associated with the file descriptoer L</"FD"> and store it to the offset $offset position of the string $string.
+Perform read operation.
 
-And returns the read length.
+This method just calls L</"recv"> method given $buffer, $length, $flags set to 0, $offset, and returns its return values.
 
-This method calls L</"recv"> method given the arguments given to this method and returns its return values.
+Exceptions:
+
+Exceptions thrown by L</"recv"> method could be thrown.
 
 =head2 write
 
 C<method write : int ($buffer : string, $length : int = -1, $offset : int = 0);>
 
-Writes the length $length from the offset $offset of the string $buffer to the stream associated with the file descriptoer L</"FD">.
+Perform write operation.
 
-And returns the write length.
-
-This method calls L</"send"> method given the arguments given to this method and returns its return values.
+This method just calls L</"send"> method given $buffer, $flags set to 0, $length, $offset, and returns its return values.
 
 Exceptions:
 
@@ -238,9 +342,9 @@ Exceptions thrown by L</"send"> method could be thrown.
 
 C<method sockname : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
 
-Returns the local socket address of the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
+Returns a L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> for a local address.
 
-This method calls L<Sys#getsockname|SPVM::Sys/"getsockname"> method.
+This method calls L<Sys#getsockname|SPVM::Sys/"getsockname"> method given the vlaue of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
 
 Exceptions:
 
@@ -250,9 +354,9 @@ Exceptions thrown by L<Sys#getsockname|SPVM::Sys/"getsockname"> method could be
 
 C<method peername : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
 
-Returns the peer socket address of the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
+Returns a L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> for a remote address.
 
-This method calls L<Sys#getpeername|SPVM::Sys/"getpeername"> method.
+This method calls L<Sys#getpeername|SPVM::Sys/"getpeername"> method given the vlaue of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
 
 Exceptions:
 
@@ -262,15 +366,17 @@ Exceptions thrown by L<Sys#getpeername|SPVM::Sys/"getpeername"> method could be
 
 C<method connected : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
 
-If L</"peername"> method does not throw an exception, returns the return value, otherwise returns undef.
+Checks if the socket is connected.
+
+If L</"peername"> method does not throw an exception, returns a L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> object, otherwise returns undef.
 
 =head2 atmark
 
 C<method atmark : int ();>
 
-If the socket assciated with the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field is currently positioned at the urgent data mark, returns 1, otherwise returns 0.
+Perform atmark operation and returns the result.
 
-This method calls L<Sys::Socket#sockatmark|SPVM::Sys::Socket/"sockatmark"> method.
+This method just calls L<Sys::Socket#sockatmark|SPVM::Sys::Socket/"sockatmark"> method given the vlaue of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
 
 Exceptions:
 
@@ -280,9 +386,11 @@ Exceptions thrown by L<Sys::Socket#sockatmark|SPVM::Sys::Socket/"sockatmark"> me
 
 C<method sockopt : int ($level : int, $option_name : int);>
 
+Perform sockopt operation and returns the result.
+
 Gets a socket option of the file descriptor stored in L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field given the socket level $level and the option name $option_name.
 
-This method calls L<Sys#getsockopt|SPVM::Sys/"getsockopt"> method given the arguments given to this method and returns its return value.
+This method just calls L<Sys#getsockopt|SPVM::Sys/"getsockopt"> method given the vlaue of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $level, $opton_name, and its return value.
 
 Exceptions:
 
@@ -292,78 +400,14 @@ Exceptions thrown by L<Sys#getsockopt|SPVM::Sys/"getsockopt"> method could be th
 
 C<method setsockopt : void ($level : int, $option_name : int, $option_value : object of string|L<Int|SPVM::Int>);>
 
-Sets a socket option of the file descriptor stored in L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field given the socket level $level, the option name $option_name, and the option value $option_value.
+Perform setsockopt operation.
 
-This method calls L<Sys#setsockopt|SPVM::Sys/"setsockopt"> method given the arguments given to this method.
+This method just calls L<Sys#setsockopt|SPVM::Sys/"setsockopt"> method given the arguments given the vlaue of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $level, $option_name.
 
 Exceptions:
 
 Exceptions thrown by L<Sys#setsockopt|SPVM::Sys/"setsockopt"> method could be thrown.
 
-=head2 connect
-
-C<protected method connect : void ($sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
-
-=head2 socket
-
-C<protected method socket : void ();>
-
-Opens a socket using L</"Domain"> field, L</"Type"> field, and L</"Protocal"> field.
-
-L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field is set to the file descriptor of the opened socket.
-
-This method calls L<Sys#socket|Sys/"socket"> method.
-
-Exceptions:
-
-Exceptions thrown by L<Sys#socket|Sys/"socket"> method could be thrown.
-
-=head2 bind
-
-C<protected method bind : void ($sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
-
-Does the same thing that L<bind|https://linux.die.net/man/2/bind> system call does given a socket address $sockaddr and the file descriptor stored in L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
-
-This method calls L<Sys#bind|SPVM::Sys|/"bind">.
-
-Exceptions:
-
-Exceptions thrown by L<Sys#bind|SPVM::Sys|/"bind"> method could be thrown.
-
-=head2 listen
-
-C<protected method listen : void ();>
-
-Does the same thing that L<listen|https://linux.die.net/man/2/listen> system call does given the file descriptor L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field.
-
-This method calls L<Sys#listen|SPVM::Sys|/"listen">.
-
-Exceptions:
-
-Exceptions thrown by L<Sys#listen|SPVM::Sys|/"listen"> method could be thrown.
-
-=head2 set_blocking
-
-C<method set_blocking : void ($blocking : int);>
-
-This method is the same as L<IO::Handle#set_blocking|SPVM::IO::Handle/"set_blocking"> method, but if a true value is given to $blocking, an exception is thrown.
-
-Exceptions:
-
-Calling set_blocking method given a true value on an IO::Socket object is forbidden.
-
-=head1 Well Known Child Classes
-
-=over 2
-
-=item * L<IO::Socket::IP|SPVM::IO::Socket::IP>
-
-=item * L<IO::Socket::INET|SPVM::IO::Socket::INET>
-
-=item * L<IO::Socket::INET6|SPVM::IO::Socket::INET6>
-
-=back
-
 =head1 See Also
 
 =over 2
@@ -374,6 +418,10 @@ Calling set_blocking method given a true value on an IO::Socket object is forbid
 
 =back
 
+=head1 Porting
+
+This class is a Perl's L<IO::Socket|IO::Socket> porting to L<SPVM>.
+
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
