@@ -12,14 +12,14 @@ SPVM::IO::Socket::INET6 - IPv6 Sockets
   
   my $host = "google.com";
   my $port = 80;
-  my $io_socket = IO::Socket::INET6->new({
+  my $socket = IO::Socket::INET6->new({
     PeerAddr => $host,
     PeerPort => $port
   });
 
 =head1 Description
 
-The IO::Socket::INET6 class in L<SPVM> has methods to create IPv6 Sockets.
+IO::Socket::INET6 class in L<SPVM> represents a IPv6 Socket.
 
 =head1 Super Class
 
@@ -31,17 +31,13 @@ L<IO::Socket::IP|SPVM::IO::Socket::IP>
 
 C<static method new : L<IO::Socket::INET6|SPVM::IO::Socket::INET6> ($options : object[] = undef);>
 
-Same as L<SPVM::IO::Socket::IP#new> method, but the C<Domain> option is set to the return value of L<Sys::Socket::Constant#AF_INET6|SPVM::Sys::Socket::Constant/AF_INET6> method.
-
-Options:
-
-The options for L<IO::Socket#new|SPVM::IO::Socket/"new"> method are available.
+This method is the same as L<SPVM::IO::Socket::IP#new> method, but the C<Domain> option is always set to C<AF_INET6>.
 
 =head2 accept
 
 C<method accept : L<IO::Socket::INET6|SPVM::IO::Socket::INET6> ($peer_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[] = undef);>
 
-Calls L<accept|SPVM::IO::Socke/"new"> method of its super class given the argument given to this method and returns its return value.
+This method is the same as L<accept|SPVM::IO::Socket/"accept"> method, but its return type is different.
 
 =head1 Copyright & License
 
